﻿using AutoMapper;
using IdentityServer.Application.Commands;
using IdentityServer.Application.Services;
using IdentityServer.PublishedLanguage.Dto;
using MediatR;
using Microsoft.Extensions.Logging;
using System.Threading;
using System.Threading.Tasks;

namespace IdentityServer.Application.CommandHandlers
{
    public class AuthenticateUserHandler : IRequestHandler<AuthenticateUser, Token>
    {
        private readonly IUserService _userService;
        private readonly IMapper _mapper;
        private readonly ILogger<AuthenticateUserHandler> _logger;

        public AuthenticateUserHandler(IUserService userService, IMapper mapper, ILogger<AuthenticateUserHandler> logger)
        {
            _userService = userService;
            _mapper = mapper;
            _logger = logger;
        }

        public async Task<Token> Handle(AuthenticateUser command, CancellationToken cancellationToken)
        {
            var internalToken = await _userService.Authenticate(command.UserName, command.Password);
            if (internalToken == null)
            {
                _logger.LogDebug($"Authentication failed for user '{command.UserName}'.");
                return null;
            }

            _logger.LogDebug($"Authentication succeeded for user '{command.UserName}'.");
            var token = _mapper.Map<Token>(internalToken);
            return token;
        }
    }
}
